@@ -5,7 +5,7 @@ package WWW::YaCyBlacklist;
 # ABSTRACT: a Perl module to parse and execute YaCy blacklists
 
 our $AUTHORITY = 'cpan:IBRAUN';
-$WWW::YaCyBlacklist::VERSION = '0.1';
+$WWW::YaCyBlacklist::VERSION = '0.2';
 
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -35,13 +35,6 @@ has 'file_charset' => (
     init_arg => undef,
 );
 
-has 'lines' => (
-    is  => 'rw',
-    isa => 'Int',
-    default => 0,
-    init_arg => undef,
-);
-
 has 'origorder' => (
     is  => 'rw',
     isa => 'Int',
@@ -59,7 +52,7 @@ has 'sortorder' => (
 
 has 'sorting' => (
     is  => 'rw',
-    isa => enum([qw[ alphabetical length origorder random reverse_host ]]),,
+    isa => enum([qw[ alphabetical length origorder random reverse_host ]]),
     default => 'origorder',
 );
 
@@ -103,7 +96,6 @@ sub read_from_files {
     my @lines;
 
     grep { push( @lines, io( $_ )->encoding( $self->file_charset )->slurp ) } @files;
-    $self->lines(scalar @lines);
     $self->read_from_array( @lines );
 }
 
@@ -209,7 +201,7 @@ WWW::YaCyBlacklist - a Perl module to parse and execute YaCy blacklists
 
 =head1 VERSION
 
-version 0.1
+version 0.2
 
 =head1 SYNOPSIS
 
@@ -299,10 +291,6 @@ Prints the current list to a file. Executes C<sort_list( )>.
 
 YaCy does not allow host patterns with to stars at the time being. C<WWW::YaCyBlacklist> does not check for this but simply executes.
 
-=head1 Source
-
-L<De:Blacklists|https://wiki.yacy.net/index.php/De:Blacklists> (German).
-
 If there is something you would like to tell me, there are different channels for you:
 
 =over
@@ -325,6 +313,10 @@ L<Contact form on my homepage|https://ingram-braun.net/erga/legal-notice-and-con
 
 =back
 
+=head1 Source
+
+L<De:Blacklists|https://wiki.yacy.net/index.php/De:Blacklists> (German).
+
 =head1 See also
 
 =over
